<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AppendDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="432"/>
        <source>Add files to the current archive</source>
        <translation>Afegeix fitxers a l&apos;arxiu actual</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="437"/>
        <source>Use password</source>
        <translation>Usa la contrasenya</translation>
    </message>
</context>
<context>
    <name>CalculateSizeThread</name>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="68"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="136"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>El fitxer original de %1 no existeix. Si us plau, comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="70"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="138"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 no existeix al disc. Si us plau, comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="79"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="147"/>
        <source>You do not have permission to compress %1</source>
        <translation>No teniu permís per comprimir %1</translation>
    </message>
</context>
<context>
    <name>CommentProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="234"/>
        <source>Updating the comment...</source>
        <translation>S&apos;actualitza el comentari...</translation>
    </message>
</context>
<context>
    <name>CompressPage</name>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="76"/>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>Please add files</source>
        <translation>Si us plau, afegiu-hi fitxers.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
</context>
<context>
    <name>CompressSettingPage</name>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="143"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="226"/>
        <source>New Archive</source>
        <translation>Arxiu nou</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="204"/>
        <source>Advanced Options</source>
        <translation>Opcions avançades</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="208"/>
        <source>Compression method</source>
        <translation>Mètode de compressió</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="211"/>
        <source>Encrypt the archive</source>
        <translation>Xifra el fitxer</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="213"/>
        <source>CPU threads</source>
        <translation>Fils de la CPU</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="215"/>
        <source>Encrypt the file list too</source>
        <translation>Xifra també la llista de fitxers</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="217"/>
        <source>Split to volumes</source>
        <translation>Divideix en volums</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="219"/>
        <source>Comment</source>
        <translation>Comentari</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="221"/>
        <source>Compress</source>
        <comment>button</comment>
        <translation>Comprimeix</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Store</source>
        <translation>Emmagatzematge</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fastest</source>
        <translation>Rapidíssim</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fast</source>
        <translation>Ràpid</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Good</source>
        <translation>Bo</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Best</source>
        <translation>Millor</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>Single thread</source>
        <translation>Fil únic</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>2 threads</source>
        <translation>2 fils</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>4 threads</source>
        <translation>4 fils</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>8 threads</source>
        <translation>8 fils</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="257"/>
        <source>Support zip, 7z type only</source>
        <translation>Només compatible amb zip i 7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="260"/>
        <source>Support 7z type only</source>
        <translation>Només compatible amb 7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="272"/>
        <source>Enter up to %1 characters</source>
        <translation>Escriviu fins a %1 caràcters.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="293"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="294"/>
        <source>Save to</source>
        <translation>Desa a</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="483"/>
        <source>Invalid file name</source>
        <translation>Nom de fitxer no vàlid</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="489"/>
        <source>Please enter the path</source>
        <translation>Si us plau, introduïu el camí.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="494"/>
        <source>The path does not exist, please retry</source>
        <translation>El camí no existeix. Torneu-ho a provar!</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="499"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>No teniu permís per desar fitxers aquí. Si us plau, canvieu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="507"/>
        <source>Too many volumes, please change and retry</source>
        <translation>Massa volums. Si us plau, canvieu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="516"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="544"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 no existeix al disc. Si us plau, comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="522"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="551"/>
        <source>You do not have permission to compress %1</source>
        <translation>No teniu permís per comprimir %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="542"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>El fitxer original de %1 no existeix. Si us plau, comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="577"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Reemplaça</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="691"/>
        <source>Total size: %1</source>
        <translation>Mida total: %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="711"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>El nom és igual al de l&apos;arxiu comprimit. Si us plau, useu-ne un altre.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="719"/>
        <source>The password for ZIP volumes cannot be in Chinese</source>
        <translation>La contrasenya per als volums ZIP no pot ser en xinès.</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Ja existeix un altre fitxer amb el mateix nom. Voleu reemplaçar-lo?</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="823"/>
        <source>Only Chinese and English characters and some symbols are supported</source>
        <translation>Només s&apos;admeten caràcters xinesos i anglesos i alguns símbols.</translation>
    </message>
</context>
<context>
    <name>CompressView</name>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="284"/>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="298"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="301"/>
        <source>Open with</source>
        <translation>Obre amb</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="305"/>
        <location filename="../src/source/tree/compressview.cpp" line="407"/>
        <source>Select default program</source>
        <translation>Trieu el programa per defecte</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>It will permanently delete the file(s). Are you sure you want to continue?</source>
        <translation>S&apos;eliminaran permanentment els fitxers. Segur que voleu continuar?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <location filename="../src/source/tree/compressview.cpp" line="381"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="382"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Afegeix</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="380"/>
        <source>Do you want to add the archive to the list or open it in new window?</source>
        <translation>Voleu afegir el fitxer a la llista o obrir-lo en una finestra nova?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="383"/>
        <source>Open in new window</source>
        <translation>Obre en una finestra nova</translation>
    </message>
</context>
<context>
    <name>ConvertDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="306"/>
        <source>Changes to archives in this file type are not supported. Please convert the archive format to save the changes.</source>
        <translation>Els canvis dels arxius d&apos;aquest tipus de fitxers no són compatibles. Convertiu el format d’arxiu per desar els canvis.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="314"/>
        <source>Convert the format to:</source>
        <translation>Converteix-ne el format a:</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="338"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="339"/>
        <source>Convert</source>
        <comment>button</comment>
        <translation>Converteix</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <location filename="../src/source/tree/datamodel.cpp" line="70"/>
        <source>item(s)</source>
        <translation>element/s</translation>
    </message>
</context>
<context>
    <name>FailurePage</name>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="87"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>L&apos;extracció ha fallat.</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="100"/>
        <source>Damaged file, unable to extract</source>
        <translation>Fitxer malmès, no es pot extreure.</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="105"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Torna-ho a provar</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="108"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="56"/>
        <source>Drag file or folder here</source>
        <translation>Arrossegueu un fitxer o una carpeta aquí.</translation>
    </message>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="58"/>
        <source>Select File</source>
        <translation>Trieu un fitxer</translation>
    </message>
</context>
<context>
    <name>LoadCorruptQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="525"/>
        <source>The archive is damaged</source>
        <translation>L&apos;arxiu està danyat.</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="528"/>
        <source>Open as read-only</source>
        <translation>L&apos;obertura és només de lectura.</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="529"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>LoadingPage</name>
    <message>
        <location filename="../src/source/page/loadingpage.cpp" line="65"/>
        <source>Loading, please wait...</source>
        <translation>Es carrega. Espereu, si us plau...</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <location filename="../src/main.cpp" line="61"/>
        <source>Archive Manager</source>
        <translation>Gestor d&apos;arxius</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Archive Manager is a fast and lightweight application for creating and extracting archives.</source>
        <translation>El Gestor d&apos;arxius és una aplicació lleugera i ràpida per crear i descomprimir arxius.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="172"/>
        <location filename="../src/source/mainwindow.cpp" line="191"/>
        <location filename="../src/source/mainwindow.cpp" line="440"/>
        <source>Open file</source>
        <translation>Obre el fitxer</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="173"/>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="294"/>
        <location filename="../src/source/mainwindow.cpp" line="304"/>
        <source>Create New Archive</source>
        <translation>Crea un nou fitxer</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="345"/>
        <source>Converting</source>
        <translation>Es converteix</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="352"/>
        <source>Updating comments</source>
        <translation>S&apos;actualitzen els comentaris.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="2068"/>
        <location filename="../src/source/mainwindow.cpp" line="2090"/>
        <location filename="../src/source/mainwindow.cpp" line="2115"/>
        <source>Plugin error</source>
        <translation>Error del connector</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1302"/>
        <source>Adding successful</source>
        <translation>Addició correcta</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2139"/>
        <source>No data in it</source>
        <translation>No hi ha dades.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1522"/>
        <source>Adding canceled</source>
        <translation>S&apos;ha cancel·lat l&apos;addició.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1620"/>
        <source>Adding failed</source>
        <translation>Ha fallat l&apos;addició.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1673"/>
        <source>Extraction failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1700"/>
        <location filename="../src/source/mainwindow.cpp" line="2135"/>
        <source>Failed to create &quot;%1&quot;</source>
        <translation>Ha fallat crear &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1822"/>
        <source>Open failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2041"/>
        <source>Compression successful</source>
        <translation>Compressió correcta</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2047"/>
        <source>The file name is too long, so the first 60 characters have been intercepted as the file name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2076"/>
        <location filename="../src/source/mainwindow.cpp" line="2143"/>
        <source>Insufficient disk space</source>
        <translation>Espai de disc insuficient</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2102"/>
        <location filename="../src/source/mainwindow.cpp" line="2123"/>
        <source>Some volumes are missing</source>
        <translation>Manquen alguns volums</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2127"/>
        <source>Wrong password, please retry</source>
        <translation>Contrasenya incorrecta. Torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2131"/>
        <location filename="../src/source/mainwindow.cpp" line="2155"/>
        <source>The file name is too long. Keep the name within 60 characters please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2152"/>
        <source>Conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2290"/>
        <source>Select file</source>
        <translation>Seleccioneu un fitxer</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3102"/>
        <source>Enter up to %1 characters</source>
        <translation>Escriviu fins a %1 caràcters.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="196"/>
        <location filename="../src/source/mainwindow.cpp" line="2978"/>
        <source>File info</source>
        <translation>Informació del fitxer</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Do you want to delete the archive?</source>
        <translation>Voleu eliminar l&apos;arxiu?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="553"/>
        <source>%1 was changed on the disk, please import it again.</source>
        <translation>%1 ha canviat al disc. Si us plau, torneu-lo a importar.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="73"/>
        <source>Archive Manager</source>
        <translation>Gestor d&apos;arxius</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>No teniu permís per desar fitxers aquí. Si us plau, canvieu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="317"/>
        <source>Adding files to %1</source>
        <translation>S&apos;afegeixen fitxers a %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="324"/>
        <source>Compressing</source>
        <translation>Es comprimeix</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="331"/>
        <source>Extracting</source>
        <translation>S&apos;extreu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="338"/>
        <source>Deleting</source>
        <translation>S&apos;elimina</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="443"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="513"/>
        <location filename="../src/source/mainwindow.cpp" line="2802"/>
        <source>Loading, please wait...</source>
        <translation>Es carrega. Espereu, si us plau...</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <source>Are you sure you want to stop the ongoing task?</source>
        <translation>Segur que voleu interrompre la tasca activa?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1308"/>
        <location filename="../src/source/mainwindow.cpp" line="1434"/>
        <source>Updating, please wait...</source>
        <translation>S&apos;actualitza. Espereu, si us plau...</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1695"/>
        <source>File name too long</source>
        <translation>Nom del fitxer massa llarg.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2072"/>
        <source>Failed to create file</source>
        <translation>Ha fallat crear el fitxer.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2065"/>
        <source>Compression failed</source>
        <translation>La compressió ha fallat.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Reemplaça</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2464"/>
        <source>Find directory</source>
        <translation>Troba un directori</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2087"/>
        <source>Open failed</source>
        <translation>Ha fallat l&apos;obertura.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1616"/>
        <location filename="../src/source/mainwindow.cpp" line="1690"/>
        <location filename="../src/source/mainwindow.cpp" line="1765"/>
        <location filename="../src/source/mainwindow.cpp" line="1820"/>
        <location filename="../src/source/mainwindow.cpp" line="2098"/>
        <source>Wrong password</source>
        <translation>Contrasenya incorrecta</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="659"/>
        <source>The file format is not supported by Archive Manager</source>
        <translation>El format del fitxer no l&apos;admet el Gestor d&apos;arxius.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="556"/>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="666"/>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <location filename="../src/source/mainwindow.cpp" line="2722"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <source>You do not have permission to load %1</source>
        <translation>No teniu permís per carregar %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <source>No such file or directory</source>
        <translation>No hi ha tal fitxer o directori.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1350"/>
        <source>Extraction successful</source>
        <comment>提取成功</comment>
        <translation>Extracció correcta</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1543"/>
        <source>Extraction canceled</source>
        <comment>取消提取</comment>
        <translation>S&apos;ha cancel·lat l&apos;extracció.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1685"/>
        <location filename="../src/source/mainwindow.cpp" line="1760"/>
        <location filename="../src/source/mainwindow.cpp" line="2094"/>
        <location filename="../src/source/mainwindow.cpp" line="2119"/>
        <source>The archive is damaged</source>
        <translation>L&apos;arxiu està danyat.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2045"/>
        <source>Extraction successful</source>
        <comment>解压成功</comment>
        <translation>Extracció correcta</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2051"/>
        <source>Conversion successful</source>
        <translation>Conversió correcta</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2112"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>L&apos;extracció ha fallat.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2282"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2286"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2294"/>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2302"/>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2314"/>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2392"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>El nom és igual al de l&apos;arxiu comprimit. Si us plau, useu-ne un altre.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Ja existeix un altre fitxer amb el mateix nom. Voleu reemplaçar-lo?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2543"/>
        <source>You cannot add the archive to itself</source>
        <translation>No podeu afegir un arxiu a si mateix.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <source>You cannot add files to archives in this file type</source>
        <translation>No podeu afegir fitxers d&apos;aquest tipus a arxius.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Actualitza</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3002"/>
        <source>Basic info</source>
        <translation>Informació bàsica</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3018"/>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3019"/>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3020"/>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3021"/>
        <source>Time created</source>
        <translation>Hora de creació</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3022"/>
        <source>Time accessed</source>
        <translation>Hora d&apos;accés</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3023"/>
        <source>Time modified</source>
        <translation>Modificat</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3033"/>
        <source>Archive</source>
        <translation>Arxiva</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3064"/>
        <source>Comment</source>
        <translation>Comentari</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="656"/>
        <source>Please check the file association type in the settings of Archive Manager</source>
        <translation>Si us plau, comproveu el tipus d&apos;associació de fitxers a la configuració del Gestor d&apos;arxius.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <source>The archive was changed on the disk, please import it again.</source>
        <translation>L&apos;arxiu ha canviat al disc. Si us plau, torneu-lo a importar.</translation>
    </message>
</context>
<context>
    <name>MimeTypeDisplayManager</name>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="46"/>
        <source>Directory</source>
        <translation>Directori</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="47"/>
        <source>Application</source>
        <translation>Aplicació</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="48"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="49"/>
        <source>Audio</source>
        <translation>Àudio</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="50"/>
        <source>Image</source>
        <translation>Imatge</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="51"/>
        <source>Archive</source>
        <translation>Arxiva</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="53"/>
        <source>Executable</source>
        <translation>Executable</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="52"/>
        <source>Document</source>
        <translation>Document</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="54"/>
        <source>Backup file</source>
        <translation>Fitxer de còpia de seguretat</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="55"/>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="280"/>
        <source>Open with</source>
        <translation>Obre amb</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="300"/>
        <source>Add other programs</source>
        <translation>Afegeix altres programes</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="301"/>
        <source>Set as default</source>
        <translation>Estableix-lo per defecte</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="303"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="304"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="308"/>
        <source>Recommended Applications</source>
        <translation>Aplicacions recomanades</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="310"/>
        <source>Other Applications</source>
        <translation>Altres aplicacions</translation>
    </message>
</context>
<context>
    <name>PasswordNeededQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="394"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Fitxer encriptat. Si us plau, introduïu-ne la contrasenya.</translation>
    </message>
</context>
<context>
    <name>PreviousLabel</name>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="52"/>
        <source>Current path:</source>
        <translation>Camí actual:</translation>
    </message>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="60"/>
        <source>Back to: %1</source>
        <translation>Enrere a: %1</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="52"/>
        <source>%1 task(s) in progress</source>
        <translation>%1 tasca/ques en curs</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="59"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="102"/>
        <source>Task</source>
        <translation>Tasca</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="65"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="113"/>
        <source>Extracting</source>
        <translation>S&apos;extreu</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="192"/>
        <source>Are you sure you want to stop the extraction?</source>
        <translation>Segur que voleu interrompre&apos;n l&apos;extracció?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
</context>
<context>
    <name>ProgressPage</name>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="314"/>
        <location filename="../src/source/page/progresspage.cpp" line="317"/>
        <location filename="../src/source/page/progresspage.cpp" line="320"/>
        <source>Speed</source>
        <comment>compress</comment>
        <translation>Velocitat</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="149"/>
        <source>Calculating...</source>
        <translation>Es calcula...</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="324"/>
        <location filename="../src/source/page/progresspage.cpp" line="326"/>
        <source>Speed</source>
        <comment>delete</comment>
        <translation>Velocitat</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="338"/>
        <location filename="../src/source/page/progresspage.cpp" line="340"/>
        <location filename="../src/source/page/progresspage.cpp" line="342"/>
        <source>Speed</source>
        <comment>convert</comment>
        <translation>Velocitat</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="330"/>
        <location filename="../src/source/page/progresspage.cpp" line="332"/>
        <location filename="../src/source/page/progresspage.cpp" line="334"/>
        <source>Speed</source>
        <comment>uncompress</comment>
        <translation>Velocitat</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="310"/>
        <source>Time left</source>
        <translation>Temps restant</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="122"/>
        <source>Compressing</source>
        <translation>Es comprimeix</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="124"/>
        <source>Deleting</source>
        <translation>S&apos;elimina</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="126"/>
        <source>Converting</source>
        <translation>Es converteix</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="128"/>
        <location filename="../src/source/page/progresspage.cpp" line="147"/>
        <source>Updating the comment...</source>
        <translation>S&apos;actualitza el comentari...</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="130"/>
        <source>Extracting</source>
        <translation>S&apos;extreu</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="141"/>
        <location filename="../src/source/page/progresspage.cpp" line="178"/>
        <location filename="../src/source/page/progresspage.cpp" line="358"/>
        <source>Pause</source>
        <comment>button</comment>
        <translation>Interromp</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="177"/>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="354"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continua</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="376"/>
        <source>Are you sure you want to stop the decompression?</source>
        <translation>Segur que voleu interrompre&apos;n la descompressió?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="378"/>
        <source>Are you sure you want to stop the deletion?</source>
        <translation>Segur que voleu interrompre&apos;n la supressió?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="374"/>
        <location filename="../src/source/page/progresspage.cpp" line="380"/>
        <source>Are you sure you want to stop the compression?</source>
        <translation>Segur que voleu interrompre&apos;n la compressió?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="382"/>
        <source>Are you sure you want to stop the conversion?</source>
        <translation>Segur que voleu interrompre&apos;n la conversió?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Time modified</source>
        <translation>Modificat</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2821"/>
        <source>%1 changed. Do you want to save changes to the archive?</source>
        <translation>%1 ha canviat. Voleu desar els canvis a l&apos;arxiu?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="26"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="27"/>
        <source>Extraction</source>
        <translation>Extracció</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="28"/>
        <source>Auto create a folder for multiple extracted files</source>
        <translation>Crea una carpeta automàticament per a l&apos;extracció de múltiples fitxers.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="29"/>
        <source>Show extracted files when completed</source>
        <translation>Mostra els fitxers extrets en acabar.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="30"/>
        <source>File Management</source>
        <translation>Gestió de fitxers</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="31"/>
        <source>Delete files after compression</source>
        <translation>Elimina els fitxers després de la compressió.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="32"/>
        <source>Files Associated</source>
        <translation>Fitxers associats</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="33"/>
        <source>File Type</source>
        <translation>Tipus de fitxer</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="202"/>
        <location filename="../src/source/dialog/popupdialog.cpp" line="208"/>
        <location filename="../3rdparty/interface/queries.cpp" line="244"/>
        <source>Skip</source>
        <comment>button</comment>
        <translation>Omet</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="203"/>
        <source>Merge</source>
        <comment>button</comment>
        <translation>Fusiona</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="206"/>
        <location filename="../3rdparty/interface/queries.cpp" line="221"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Ja existeix un altre fitxer amb el mateix nom. Voleu reemplaçar-lo?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="209"/>
        <location filename="../3rdparty/interface/queries.cpp" line="245"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Reemplaça</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="477"/>
        <location filename="../3rdparty/interface/queries.cpp" line="405"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="478"/>
        <location filename="../3rdparty/interface/queries.cpp" line="406"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="200"/>
        <source>Another folder with the same name already exists, replace it?</source>
        <translation>Ja existeix una altra carpeta amb el mateix nom. Voleu reemplaçar-la?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="212"/>
        <location filename="../3rdparty/interface/queries.cpp" line="226"/>
        <source>Apply to all</source>
        <translation>Aplica-ho a tot</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="195"/>
        <source>Current directory</source>
        <translation>Directori actual</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="125"/>
        <source>Clear All</source>
        <translation>Neteja-ho tot</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="124"/>
        <source>Select All</source>
        <comment>button</comment>
        <translation>Selecciona-ho tot</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="126"/>
        <source>Recommended</source>
        <translation>Recomanat</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="160"/>
        <source>Extract archives to</source>
        <translation>Extreu els arxius a</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="205"/>
        <source>Other directory</source>
        <translation>Altre directori</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="200"/>
        <source>Desktop</source>
        <translation>Escriptori</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="272"/>
        <source>Delete archives after extraction</source>
        <translation>Elimina els arxius després de l&apos;extracció.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="299"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="302"/>
        <source>Ask for confirmation</source>
        <translation>Demana&apos;n la confirmació.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="305"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
</context>
<context>
    <name>SuccessPage</name>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="79"/>
        <source>Compression successful</source>
        <translation>Compressió correcta</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="89"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="92"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
</context>
<context>
    <name>UnCompressPage</name>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="75"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="87"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="116"/>
        <source>Extract to:</source>
        <translation>Extreu a:</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="117"/>
        <source>Extract</source>
        <comment>button</comment>
        <translation>Extreu</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="191"/>
        <source>The default extraction path does not exist, please retry</source>
        <translation>El camí d&apos;extracció per defecte no existeix. Torneu-ho a provar, si us plau.</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="193"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>No teniu permís per desar fitxers aquí. Si us plau, canvieu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="197"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="211"/>
        <source>Find directory</source>
        <translation>Troba un directori</translation>
    </message>
</context>
<context>
    <name>UnCompressView</name>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>You cannot add the archive to itself</source>
        <translation>No podeu afegir un arxiu a si mateix.</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="618"/>
        <source>Extract</source>
        <comment>提取</comment>
        <translation>Extreu</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="620"/>
        <source>Extract to current directory</source>
        <translation>Extreu-ho al directori actual</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="622"/>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="625"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="632"/>
        <source>Open with</source>
        <translation>Obre amb</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="636"/>
        <location filename="../src/source/tree/uncompressview.cpp" line="737"/>
        <source>Select default program</source>
        <translation>Trieu el programa per defecte</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>Voleu eliminar el/s fitxer/s seleccionat/s?</translation>
    </message>
</context>
</TS>
